#include <iostream>  
#include <fstream>   // tam jest fstream
#include <cmath>     // tam jest NAN

using namespace std;

struct wektor {
	int n; // wymiar
	double *w; // elementy

	wektor( int size ) {
		w = new double[size];
		n = size;
	}

	void free() {
		delete [] w;
	}

};

ostream& operator<<(ostream& os, const wektor& w)
{
    os << "[";
	for( int i = 0; i < w.n; i++ )
		os << " " << w.w[i];
	os << " ]";
    return os;
}

double dlugosc( wektor v ) {
	double d = 0.0;
	for( int i= 0; i < v.n; i++ )
		d += v.w[i]*v.w[i];
	return sqrt(d);
}

double iloczyn( wektor p, wektor q ) {
	if( p.n != q.n )
		return NAN;
	else {
		double s = 0.0;
		for( int i= 0; i < p.n; i++ )
			s += p.w[i]*q.w[i];
		return s;
	}
}

bool znormalizowany( wektor v ) {
	double lgt = dlugosc( v );
	if( lgt == 0.0 )
		return false;
	else {
		for( int i= 0; i < v.n; i++ )
			v.w[i] /= lgt;
		return true;
	}
}

int main( int argc, char ** argv ) {
    fstream fin;

    if (argc > 1)
        fin.open(argv[1]);

	istream &in = fin.is_open() ? fin : cin;

	int n;
	in >> n;
	wektor w = wektor(n);
	for( int i= 0; i < n; i++ ) {
		in >> w.w[i];
	}
	double dw = dlugosc( w );

	cout << "||w||=" << dw << endl;

	if( znormalizowany( w ) ) {
		cout << "Po normalizacji: " << w << endl;
		cout << "||w||=" << dlugosc( w ) << endl;
	}

	if (argc > 2) {
		fin.close();
		fin.open(argv[2]);
	
		fin >> n;
		wektor u = wektor(n);
		for( int i = 0; i < n; i++ )
			fin >> u.w[i];

		cout << "||u||=" << dlugosc( u ) << endl;
		cout << "w*u=" << iloczyn( w, u ) << endl;

		u.free();
	}
	w.free();

	return 0;
}
